/*---------------------------------------------------------------------------------------------
 * Copyright (c) Bentley Systems, Incorporated. All rights reserved.
 * See LICENSE.md in the project root for license terms and full copyright notice.
 *--------------------------------------------------------------------------------------------*/
import * as React from "react";
import ReactDOM from "react-dom";
import ToastMaster from "./ToastMaster";
export default class Toaster {
    constructor() {
        this.success = this.success.bind(this);
        this.error = this.error.bind(this);
        this.informational = this.informational.bind(this);
        this.notifyHandler = null;
        this.closeAllHandler = null;
        this._bindNotify = this._bindNotify.bind(this);
        this._bindCloseAll = this._bindCloseAll.bind(this);
        const container = document.createElement("div");
        container.setAttribute("itwin-toaster-container", "");
        document.body.appendChild(container);
        ReactDOM.render(React.createElement(ToastMaster, { bindNotify: this._bindNotify, bindCloseAll: this._bindCloseAll }), container);
    }
    /* Call a Toast component with the success category */
    success(text, settings) {
        if (this.notifyHandler) {
            this.notifyHandler({
                category: "success",
                duration: settings && settings.duration ? settings.duration : undefined,
                hasCloseButton: settings && settings.hasCloseButton
                    ? settings.hasCloseButton
                    : undefined,
                link: settings && settings.link ? settings.link : undefined,
                text,
                type: settings && settings.type ? settings.type : "persisting",
            });
        }
    }
    /* Call a Toast component with the informational category */
    informational(text, settings) {
        if (this.notifyHandler) {
            this.notifyHandler({
                category: "informational",
                duration: settings && settings.duration ? settings.duration : undefined,
                hasCloseButton: settings && settings.hasCloseButton
                    ? settings.hasCloseButton
                    : undefined,
                link: settings && settings.link ? settings.link : undefined,
                text,
                type: settings && settings.type ? settings.type : "persisting",
            });
        }
    }
    /* Call a Toast component with the error category */
    error(text, settings) {
        if (this.notifyHandler) {
            this.notifyHandler({
                category: "error",
                duration: settings && settings.duration ? settings.duration : undefined,
                hasCloseButton: settings && settings.hasCloseButton
                    ? settings.hasCloseButton
                    : undefined,
                link: settings && settings.link ? settings.link : undefined,
                text,
                type: settings && settings.type ? settings.type : "persisting",
            });
        }
    }
    /* Call closeAll from ToastManager */
    closeAll() {
        if (this.closeAllHandler) {
            this.closeAllHandler();
        }
    }
    /* Bind the notify function from ToastManager */
    _bindNotify(notify) {
        this.notifyHandler = notify;
    }
    /* Bind the closeAll function from ToastManager */
    _bindCloseAll(closeAll) {
        this.closeAllHandler = closeAll;
    }
}
//# sourceMappingURL=Toaster.js.map